@@ -13,7 +13,6 @@ from cybrid_api_bank.model.account import Account
 from cybrid_api_bank.model.account_list import AccountList
 from cybrid_api_bank.model.asset import Asset
 from cybrid_api_bank.model.asset_list import AssetList
-from cybrid_api_bank.model.attestation_details import AttestationDetails
 from cybrid_api_bank.model.bank import Bank
 from cybrid_api_bank.model.bank_list import BankList
 from cybrid_api_bank.model.customer import Customer
@@ -23,8 +22,8 @@ from cybrid_api_bank.model.deposit_address_list import DepositAddressList
 from cybrid_api_bank.model.error_response import ErrorResponse
 from cybrid_api_bank.model.external_bank_account import ExternalBankAccount
 from cybrid_api_bank.model.external_bank_account_list import ExternalBankAccountList
-from cybrid_api_bank.model.identity_record import IdentityRecord
-from cybrid_api_bank.model.identity_record_list import IdentityRecordList
+from cybrid_api_bank.model.external_wallet import ExternalWallet
+from cybrid_api_bank.model.external_wallet_list import ExternalWalletList
 from cybrid_api_bank.model.identity_verification import IdentityVerification
 from cybrid_api_bank.model.identity_verification_list import IdentityVerificationList
 from cybrid_api_bank.model.identity_verification_with_details import IdentityVerificationWithDetails
@@ -36,17 +35,19 @@ from cybrid_api_bank.model.patch_external_bank_account import PatchExternalBankA
 from cybrid_api_bank.model.post_account import PostAccount
 from cybrid_api_bank.model.post_bank import PostBank
 from cybrid_api_bank.model.post_customer import PostCustomer
+from cybrid_api_bank.model.post_customer_address import PostCustomerAddress
+from cybrid_api_bank.model.post_customer_name import PostCustomerName
 from cybrid_api_bank.model.post_deposit_address import PostDepositAddress
 from cybrid_api_bank.model.post_external_bank_account import PostExternalBankAccount
-from cybrid_api_bank.model.post_identity_record import PostIdentityRecord
-from cybrid_api_bank.model.post_identity_record_attestation_details import PostIdentityRecordAttestationDetails
+from cybrid_api_bank.model.post_external_wallet import PostExternalWallet
+from cybrid_api_bank.model.post_identification_number import PostIdentificationNumber
 from cybrid_api_bank.model.post_identity_verification import PostIdentityVerification
-from cybrid_api_bank.model.post_one_time_address import PostOneTimeAddress
+from cybrid_api_bank.model.post_identity_verification_address import PostIdentityVerificationAddress
+from cybrid_api_bank.model.post_identity_verification_name import PostIdentityVerificationName
 from cybrid_api_bank.model.post_quote import PostQuote
 from cybrid_api_bank.model.post_reward import PostReward
 from cybrid_api_bank.model.post_trade import PostTrade
 from cybrid_api_bank.model.post_transfer import PostTransfer
-from cybrid_api_bank.model.post_verification_key import PostVerificationKey
 from cybrid_api_bank.model.post_workflow import PostWorkflow
 from cybrid_api_bank.model.quote import Quote
 from cybrid_api_bank.model.quote_list import QuoteList
@@ -59,8 +60,6 @@ from cybrid_api_bank.model.trade import Trade
 from cybrid_api_bank.model.trade_list import TradeList
 from cybrid_api_bank.model.transfer import Transfer
 from cybrid_api_bank.model.transfer_list import TransferList
-from cybrid_api_bank.model.verification_key import VerificationKey
-from cybrid_api_bank.model.verification_key_list import VerificationKeyList
 from cybrid_api_bank.model.workflow import Workflow
 from cybrid_api_bank.model.workflow_with_details import WorkflowWithDetails
 from cybrid_api_bank.model.workflow_with_details_all_of import WorkflowWithDetailsAllOf
